@@ -1,12 +1,11 @@
-from django.contrib.contenttypes.models import ContentType
 from django import forms
-from django.db.utils import DatabaseError
 from django.utils.translation import ugettext_lazy as _
 
 
 # Avoid using common protocol names as prefix, this could clash in the future.
 # Values starting with such prefix should be handled as external URL.
-_invalid_prefixes = ('http', 'https', 'ftp', 'sftp', 'webdav', 'webdavs', 'afp', 'smb', 'git', 'svn', 'hg')
+_invalid_prefixes = ('http', 'https', 'ftp', 'ftps', 'sftp', 'webdav', 'webdavs', 'afp', 'smb', 'git', 'svn', 'hg')
+
 
 class UrlType(object):
     def __init__(self, model, form_field, widget, title, prefix, has_id_value):
@@ -23,6 +22,9 @@ class UrlType(object):
         self.prefix = prefix
         self.has_id_value = has_id_value
 
+    def __repr__(self):
+        return "<UrlType {0}>".format(self.prefix)
+
 
 class UrlTypeRegistry(object):
     """
@@ -47,29 +49,33 @@ class UrlTypeRegistry(object):
         if any(urltype.model == ModelClass for urltype in self._url_types):
             raise ValueError("Model is already registered: '{0}'".format(ModelClass))
 
+        opts = ModelClass._meta
         try:
-            ct = ContentType.objects.get_for_model(ModelClass)
-        except DatabaseError:
-            return   # skip at first syncdb
+            opts = opts.concrete_model._meta
+        except AttributeError:  # Django 1.3
+            pass
 
         if not prefix:
             # Store something descriptive, easier to lookup from raw database content.
-            prefix = '{0}.{1}'.format(*ct.natural_key())
+            prefix = '{0}.{1}'.format(opts.app_label, opts.object_name.lower())
         if not title:
             title = ModelClass._meta.verbose_name
 
-        if prefix in _invalid_prefixes:
+        if self.is_external_url_prefix(prefix):
             raise ValueError("Invalid prefix value: '{0}'.".format(prefix))
         if self[prefix] is not None:
             raise ValueError("Prefix is already registered: '{0}'".format(prefix))
         if form_field is not None and widget is not None:
             raise ValueError("Provide either a form_field or widget; use the widget parameter of the form field instead.")
 
-        self._url_types.append(
-            UrlType(ModelClass, form_field, widget, title, prefix, has_id_value)
-        )
+        urltype = UrlType(ModelClass, form_field, widget, title, prefix, has_id_value)
+        self._url_types.append(urltype)
+        return urltype
 
 
+    def is_external_url_prefix(self, prefix):
+        return prefix in _invalid_prefixes
+
     # Accessing API is similar to `list` and '`dict`:
 
     def __iter__(self):
@@ -77,7 +83,8 @@ class UrlTypeRegistry(object):
 
 
     def __getitem__(self, prefix):
-        if prefix == 'https':
+        # Any web domain will be handled by the standard URLField.
+        if self.is_external_url_prefix(prefix):
             prefix = 'http'
 
         for urltype in self._url_types:
@@ -91,7 +98,7 @@ class UrlTypeRegistry(object):
         Return the model index for a prefix.
         """
         # Any web domain will be handled by the standard URLField.
-        if prefix == 'https':
+        if self.is_external_url_prefix(prefix):
             prefix = 'http'
 
         for i, urltype in enumerate(self._url_types):
